@@ -84,8 +84,8 @@ class AsyncIterable(Generic[T]):
         self.iterable = iterable
         self.iterator: Optional[Iterator[T]] = None
 
-        self.before = before
-        self.after = after
+        self.before: Optional[NoArgAwaitable[Any]] = before
+        self.after: Optional[NoArgAwaitable[Any]] = after
 
     def __repr__(self) -> str:
         return f'AsyncIterable({self.iterator!r}, before={self.before!r}, after={self.after!r})'
@@ -93,9 +93,6 @@ class AsyncIterable(Generic[T]):
     def __await__(self) -> Generator[Any, Any, List[T]]:
         return self.flatten().__await__()
 
-    def __iter__(self) -> NoReturn:
-        raise TypeError(f'{self.__class__.__name__!r} object is not iterable, use async for instead.')
-
     def __aiter__(self) -> "Self":
         self.iterator = iter(self.iterable)
         return self
